experimental-lowqa (0.2.1) — docs

Skip to main content
`Ctrl`+`K`

# experimental-lowqa (0.2.1)

Read the sign.

Consider sponsoring development.

(interface documentation)

## Python Version Support

This package is tested with the following Python minor versions:

- `python3.13`

- `python3.14`

## Platform Support

This package is tested on the following platforms:

- `ubuntu-latest`

- `macos-latest`

- `windows-latest`

# Introduction

This project does not require 100% unit test coverage for publishing (hence the name). All other typical Python quality assurance is still enforced.

# Internal Dependency Graph

A coarse view of the internal structure and scale of `experimental-lowqa`’s source. Generated using pydeps (via `mk python-deps`).

Interface Documentation

- experimental_lowqa package
  - Subpackages
    - experimental_lowqa.tasks package
      - Subpackages
      - Submodules
      - experimental_lowqa.tasks.conntextual module
      - experimental_lowqa.tasks.docs module
      - experimental_lowqa.tasks.python module
      - experimental_lowqa.tasks.runtimepy module
      - Module contents
  - Submodules
  - experimental_lowqa.edit module
    - `GenerateTags`
      - `GenerateTags.default_editor`
      - `GenerateTags.extra_excludes`
      - `GenerateTags.extra_source_candidates`
      - `GenerateTags.languages`
      - `GenerateTags.run()`
    - `is_local_bin()`
    - `local_bin()`
    - `local_bin_if()`
  - experimental_lowqa.env module
    - `real_sources()`
    - `source_file()`
    - `try_source()`
  - experimental_lowqa.prompts module
    - `SelectOpts`
      - `SelectOpts.allow_prompt`
      - `SelectOpts.custom_option`
      - `SelectOpts.default`
      - `SelectOpts.descriptions`
      - `SelectOpts.prompt`
    - `async_boolean_select()`
    - `async_manual_select()`
    - `boolean_select()`
    - `manual_select()`
    - `select_option()`
  - experimental_lowqa.userfs module
    - `link_local_bin()`
  - Module contents